const express = require('express');
const bodyParser = require('body-parser');

const app = express();
const port = 8829;

// 中间件
app.use(bodyParser.json({
  verify(req, res, buf, encoding) {
    // 保存原始请求体
    req.rawBody = buf.toString();
  }
}));

// 添加错误处理中间件来捕获JSON解析错误
app.use((err, req, res, next) => {
  if (err instanceof SyntaxError) {
    console.error('JSON解析错误:', err.message);
    
    // 可以查看原始请求体内容
    const rawBody = req.rawBody || req.body || '无法获取原始请求体';
    console.log('原始请求体:', rawBody);
    
    return res.status(400).json({
      error: '无效的JSON格式',
      message: err.message,
      rawBody
    });
  }
  next(err); // 传递其他错误
});

// 健康检查端点
app.get('/health', (req, res) => {
  res.status(200).json({ status: 'ok' });
});

// SQL执行端点
app.use('/', require('./routes/index'));

// 错误处理中间件
app.use((err, req, res, next) => {
  console.error('应用错误:', err);
  res.status(500).json({ 
    error: '服务器内部错误',
    message: err.message 
  });
});

// 启动服务器
app.listen(port, () => {
  console.log(`服务已启动，监听端口: ${port}`);
});

// 优雅关闭
process.on('SIGINT', async () => {
  console.log('正在关闭应用...');
  try {
    process.exit(0);
  } catch (err) {
    console.error('关闭出错:', err);
    process.exit(1);
  }
});

module.exports = app;