const express = require('express');
const router = express.Router();
const { auth } = require('../middlewares/auth');

const dmdb = require('dmdb'); // 达梦数据库驱动

// 设置返回结果格式为对象
// https://eco.dameng.com/document/dm/zh-cn/pm/nodejs-rogramming-guide.html#10.3.1.2%20%E5%B1%9E%E6%80%A7
dmdb.outFormat = dmdb.OUT_FORMAT_OBJECT;

const dmHost = '10.51.210.4';
const dmPort = 5237;
const dmDatabase = 'ZZ_ZWBH_PLANT_PROTECTION';
const dmUser = 'ZZ_ZWBH_PLANT_PROTECTION';
const dmPassword = 'Pp20210721';

const connectString = `dm://${dmUser}:${dmPassword}@${dmHost}:${dmPort}?autoCommit=false&loginEncrypt=false`;

//获取数据库连接 
async function getConnection() {
  try {
      return await dmdb.getConnection(connectString);
  } catch (err) {
      throw new Error("getConnection error: " + err.message);
  }
}

getConnection().then(client => {
  client.execute('SELECT 1');
  console.log('数据库连接成功');
  client.release();
}).catch(err => {
  console.error('数据库连接失败:', err);
  process.exit(1);
});


router.post('/', auth, async (req, res) => {
  const { sql } = req.body;

  if (!sql) {
    return res.status(400).json({ error: '缺少SQL查询语句' });
  }

  try {
    // 验证SQL是否为SELECT查询
    const normalizedSql = sql.trim().toLowerCase();
    
    if (!normalizedSql.startsWith('select ')) {
      return res.status(403).json({ 
        error: '仅允许SELECT查询', 
        message: '出于安全考虑，只允许执行SELECT语句'
      });
    }

    console.log(`[${new Date().getTime()}] 执行查询:`, sql);

    // 获取数据库连接
    const client = await getConnection();
    
    try {
      // 执行查询
      const result = await client.execute(sql);
      res.status(200).json({
        success: true,
        rows: result.rows,
        rowCount: result.rowsAffected,
        fields: result.name
      });
    } finally {
      // 释放连接回连接池
      client.release();
    }
  } catch (err) {
    console.error('查询执行失败:', err);
    res.status(500).json({
      error: '查询执行失败',
      message: err.message,
      detail: process.env.NODE_ENV === 'development' ? err.stack : undefined
    });
  }
});

module.exports = router;
